pub struct PstFileLockGuard<'a, Pst>where
Pst: PstFile,{ /* private fields */ }Expand description
This is the public interface for writing to a PST.
Implementations
Sourceimpl<'a, Pst> PstFileLockGuard<'a, Pst>where
Pst: PstFile,
impl<'a, Pst> PstFileLockGuard<'a, Pst>where
Pst: PstFile,
Sourcepub fn flush(&mut self) -> Result<()>
pub fn flush(&mut self) -> Result<()>
Explicitly flush pending updates to the PST file. This will still happen implicitly when
the PstFileLockGuard is dropped, but this allows you to handle errors.